transport: mbox: Rename dispatch_mbox to transport_mbox_dispatch

Change-Id: I7c5457099e90ea4ed498fd1898b4504f051d13fc
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/transport_mbox.c b/transport_mbox.c
index fb4c28a..352ea0b 100644
--- a/transport_mbox.c
+++ b/transport_mbox.c
@@ -586,12 +586,12 @@
 }
 
 /*
  * dispatch_mbox() - handle an mbox interrupt
  * @context:	The mbox context pointer
  *
  * Return:	0 if handled successfully otherwise negative error code
  */
-int dispatch_mbox(struct mbox_context *context)
+int transport_mbox_dispatch(struct mbox_context *context)
 {
 	int rc = 0;
 	union mbox_regs req = { 0 };
@@ -586,12 +586,12 @@
 
 /*
- * dispatch_mbox() - handle an mbox interrupt
+ * transport_mbox_dispatch() - handle an mbox interrupt
  * @context:	The mbox context pointer
  *